#include <algorithm>
#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <iomanip>
#include <iostream>
#include <queue>

using namespace std;

const int MAX = 200000;
const int debug = 0;

int n, m;
int a[MAX], v[MAX];
int nxt[MAX], prv[MAX];
bool active[MAX];
double ans1[MAX + 1], ans2[MAX + 1];

double intersection(int i, int j) {
  assert(v[i] != v[j]);
  return a[i] + v[i] * double(a[j] - a[i]) / double(v[i] - v[j]);
}

void solve(const vector<int> &r, double *ans) {
  int g = -1;
  memset(nxt, 0xff, sizeof(nxt));
  memset(prv, 0xff, sizeof(prv));
  memset(active, 0, sizeof(active));
  for (int x = 1; x <= n; x++) ans[x] = n + 1.0;
  priority_queue<pair<double, pair<int, int>>> q;
  size_t z = 0;
  for (int x = 1; x <= n; x++) {
    if (debug) {
      cout << "x = " << x << endl;
    }
    while (!q.empty() && -q.top().first <= x) {
      int i1 = q.top().second.first;
      int i2 = q.top().second.second;
      if (debug) {
        cout << "  ixn of [" << i1 << "] and [" << i2 << "] at "
             << -q.top().first << ": ";
      }
      if (active[i1] && active[i2]) {
        assert(nxt[i2] == i1);
        nxt[prv[i2]] = i1;
        prv[i1] = prv[i2];
        if (g == i2) {
          g = i1;
        } else {
          q.push(make_pair(-intersection(i1, prv[i1]), make_pair(i1, prv[i1])));
        }
        active[i2] = false;
        if (debug) {
          cout << " removed [" << i2 << "]" << endl;
        }
      } else {
        if (debug) {
          cout << " not both active" << endl;
        }
      }
      q.pop();
    }
    while (z < r.size() && a[r[z]] == x) {
      int i = r[z];
      z++;
      while (g >= 0 && v[g] <= v[i]) {
        active[g] = false;
        if (debug) {
          cout << "  popped [" << g << "]" << endl;
        }
        g = nxt[g];
        prv[g] = -1;
      }
      if (a[g] == a[i]) {
        if (debug) {
          cout << "  ignored [" << i << "]" << endl;
        }
        continue;
      }
      if (debug) {
        cout << "  inserted [" << i << "] +   ixn with [" << g << "]" << endl;
      }
      if (g >= 0) {
        prv[g] = i;
        q.push(make_pair(-intersection(g, i), make_pair(g, i)));
      }
      nxt[i] = g;
      g = i;
      active[i] = true;
    }
    if (g >= 0) {
      ans[x] = (x - a[g]) / (double)v[g];
    }
  }

  if (debug) {
    cout << "ans = ";
    for (int x = 1; x <= n; x++) {
      cout << ans[x] << ", ";
    }
    cout << endl;
  }
}

int main() {
  if (!debug) {
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
  }

  scanf("%d%d", &n, &m);
  vector<int> l, r;
  for (int i = 0; i < m; i++) {
    scanf("%d%d", &a[i], &v[i]);
    if (v[i] < 0) {
      l.push_back(i);
    } else {
      r.push_back(i);
    }
  }

  if (debug) {
    cout << fixed << setprecision(2);
  }

  sort(r.begin(), r.end(), [](int p, int q) { return a[p] < a[q]; });
  if (debug) {
    cout << "Solving >>>>>>>>>>>>>>" << endl;
  }
  solve(r, ans1);

  for (int i : l) {
    a[i] = n - a[i] + 1;
    v[i] = -v[i];
  }
  sort(l.begin(), l.end(), [](int p, int q) { return a[p] < a[q]; });
  if (debug) {
    cout << "Solving <<<<<<<<<<<<<<" << endl;
  }
  solve(l, ans2);

  int best_x = 1;
  double best_ans = 0.0;
  for (int x = 1; x <= n; x++) {
    double cur_ans = min(ans1[x], ans2[n - x + 1]);
    if (cur_ans > best_ans) {
      best_ans = cur_ans;
      best_x = x;
    }
  }
  cout << best_x << endl;

  if (!debug) {
    fclose(stdin); fclose(stdout);
  }
  return 0;
}
